[java-identity-provider COMMIT] in /trunk/idp-attribute-filter-impl/src: main/java/net/shibboleth/idp/attribute/filte...

noreply at shibboleth.net noreply at shibboleth.net
Fri Mar 15 10:16:24 EDT 2013


Author: rdw
Date: Fri Mar 15 10:16:24 2013
New Revision: 4336

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=4336&view=rev
Log:
IDP-207 reintrodduce the (compound) MatchFunctor so as to simplify the parsers.    More tests needed for the Logical Matchers.

Added:
    trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/BaseValuePredicateMatcher.java
      - copied, changed from r4330, trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/AttributeValuePredicateMatcher.java
    trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/MatchFunctor.java   (with props)
    trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/matcher/TestValuePredicateMatcher.java   (with props)
Modified:
    trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/AbstractComposedMatcher.java
    trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/AndMatcher.java
    trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/AttributeValuePredicateMatcher.java
    trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/NotMatcher.java
    trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/OrMatcher.java
    trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/ScriptedMatcher.java
    trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/matcher/AbstractComposedMatcherTest.java
    trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/matcher/AndMatcherTest.java
    trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/matcher/AttributeValuePredicateMatcherTest.java
    trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/matcher/NotMatcherTest.java
    trunk/idp-attribute-filter-impl/src/test/java/net/shibboleth/idp/attribute/filtering/impl/matcher/OrMatcherTest.java

Modified: trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/AbstractComposedMatcher.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/AbstractComposedMatcher.java?rev=4336&r1=4335&r2=4336&view=diff
==============================================================================
--- trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/AbstractComposedMatcher.java (original)
+++ trunk/idp-attribute-filter-impl/src/main/java/net/shibboleth/idp/attribute/filtering/impl/matcher/AbstractComposedMatcher.java Fri Mar 15 10:16:24 2013
@@ -24,7 +24,6 @@
 import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 
-import net.shibboleth.idp.attribute.filtering.AttributeValueMatcher;
 import net.shibboleth.utilities.java.support.annotation.constraint.NonnullElements;
 import net.shibboleth.utilities.java.support.annotation.constraint.NullableElements;
 import net.shibboleth.utilities.java.support.annotation.constraint.Unmodifiable;
@@ -41,14 +40,14 @@
 import com.google.common.collect.Iterables;
 
 /**
  * Base class for {@link AttributeValueMatcher} implementations that are compositions of other
  * {@link AttributeValueMatcher}.
  */
 public abstract class AbstractComposedMatcher extends AbstractDestructableInitializableComponent implements
-        AttributeValueMatcher, UnmodifiableComponent, ValidatableComponent {
+        MatchFunctor, UnmodifiableComponent, ValidatableComponent {
 
     /** The composed matchers. */
-    private final List<AttributeValueMatcher> matchers;
+    private final List<MatchFunctor> matchers;
 
     /**
      * Constructor.
@@ -56,8 +55,8 @@
      * @param composedMatchers matchers being composed
      */
     public AbstractComposedMatcher(@Nullable @NullableElements final 
-            Collection<AttributeValueMatcher> composedMatchers) {
-        ArrayList<AttributeValueMatcher> checkedMatchers = new ArrayList<AttributeValueMatcher>();
+            Collection<MatchFunctor> composedMatchers) {
+        ArrayList<MatchFunctor> checkedMatchers = new ArrayList<MatchFunctor>();
 
         if (composedMatchers != null) {
             CollectionSupport.addIf(checkedMatchers, composedMatchers, Predicates.notNull());
@@ -71,7 +70,7 @@
      * 
      * @return the composed matchers
      */
-    @Nonnull @NonnullElements @Unmodifiable public List<AttributeValueMatcher> getComposedMatchers() {
+    @Nonnull @NonnullElements @Unmodifiable public List<MatchFunctor> getComposedMatchers() {
         return matchers;
     }
 
@@ -85,14 +84,14 @@
@@ -41,14 +40,14 @@
 
 /**
- * Base class for {@link AttributeValueMatcher} implementations that are compositions of other
- * {@link AttributeValueMatcher}.
+ * Base class for {@link MatchFunctor} implementations that are compositions of other
+ * {@link MatchFunctor}.
  */
 public abstract class AbstractComposedMatcher extends AbstractDestructableInitializableComponent implements

[... 924 lines stripped ...]


More information about the commits mailing list